==> jc-1.4.0.tar.gz: gnu/java/rmi/registry/RegistryImpl.h <==
// public class gnu.java.rmi.registry.RegistryImpl

// class file dependencies
// @dep_class f0f8e56ab55b67bd gnu_java_rmi_registry_RegistryImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_UnicastRemoteObject

#include "java/rmi/server/UnicastRemoteObject.h"

#ifndef _JC_gnu_java_rmi_registry_RegistryImpl_H_
#define _JC_gnu_java_rmi_registry_RegistryImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs	_jc_gnu_java_rmi_registry_RegistryImpl$sub_refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$refs	_jc_gnu_java_rmi_registry_RegistryImpl$refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl$nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$object	_jc_gnu_java_rmi_registry_RegistryImpl$object;

typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vmethods	_jc_gnu_java_rmi_registry_RegistryImpl$vmethods;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vtable	_jc_gnu_java_rmi_registry_RegistryImpl$vtable;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vtype	_jc_gnu_java_rmi_registry_RegistryImpl$vtype;

// Constructors
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, jint);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$_init$d02fa2c463ee2b56(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, jint, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$bind$251a9c112e05991e(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern _jc_object_array *_jc_gnu_java_rmi_registry_RegistryImpl$method$list$9e09da44f0278aa5(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *);
extern struct _jc_object *_jc_gnu_java_rmi_registry_RegistryImpl$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$rebind$082655182723d0d0(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$bind$251a9c112e05991e;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$list$9e09da44f0278aa5;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$lookup$c76567b1fb804127;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$rebind$082655182723d0d0;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$unbind$6f23bcd0c5499698;

// Static methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$help$ed44886e9089d90b(_jc_env *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$version$248a7a0f0d347d2d(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_rmi_registry_RegistryImpl$vmethods {
	void	(*bind$251a9c112e05991e)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	_jc_object_array	*(*list$9e09da44f0278aa5)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *);
	struct _jc_object	*(*lookup$c76567b1fb804127)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *);
	void	(*rebind$082655182723d0d0)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *);
	void	(*unbind$6f23bcd0c5499698)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_rmi_registry_RegistryImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
	_jc_gnu_java_rmi_registry_RegistryImpl$vmethods	gnu_java_rmi_registry_RegistryImpl;
};

// Vtype
struct _jc_gnu_java_rmi_registry_RegistryImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_registry_RegistryImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs {
	struct _jc_java_util_Hashtable$object	*bindings;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl$refs {
    _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs	gnu_java_rmi_registry_RegistryImpl;
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
    _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs	gnu_java_rmi_registry_RegistryImpl;
};

// Object instance structure
struct _jc_gnu_java_rmi_registry_RegistryImpl$object {
	_jc_gnu_java_rmi_registry_RegistryImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_registry_RegistryImpl$vtype	*vtype;
	_jc_gnu_java_rmi_registry_RegistryImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_registry_RegistryImpl$vtype _jc_gnu_java_rmi_registry_RegistryImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_registry_RegistryImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_registry_RegistryImpl$class_object;

#endif	/* _JC_gnu_java_rmi_registry_RegistryImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/registry/RegistryImpl.h <==
// public class gnu.java.rmi.registry.RegistryImpl

// class file dependencies
// @dep_class e33ad900f7afde16 gnu_java_rmi_registry_RegistryImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_UnicastRemoteObject

#include "java/rmi/server/UnicastRemoteObject.h"

#ifndef _JC_gnu_java_rmi_registry_RegistryImpl_H_
#define _JC_gnu_java_rmi_registry_RegistryImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs	_jc_gnu_java_rmi_registry_RegistryImpl$sub_refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$refs	_jc_gnu_java_rmi_registry_RegistryImpl$refs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$nonrefs	_jc_gnu_java_rmi_registry_RegistryImpl$nonrefs;
typedef struct _jc_gnu_java_rmi_registry_RegistryImpl$object	_jc_gnu_java_rmi_registry_RegistryImpl$object;

typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vmethods	_jc_gnu_java_rmi_registry_RegistryImpl$vmethods;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vtable	_jc_gnu_java_rmi_registry_RegistryImpl$vtable;
typedef const struct _jc_gnu_java_rmi_registry_RegistryImpl$vtype	_jc_gnu_java_rmi_registry_RegistryImpl$vtype;

// Constructors
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$_init$d02fa2c463ee2b56(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$bind$251a9c112e05991e(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_rmi_registry_RegistryImpl$method$list$9e09da44f0278aa5(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_rmi_registry_RegistryImpl$method$lookup$c76567b1fb804127(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$rebind$082655182723d0d0(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$unbind$6f23bcd0c5499698(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$bind$251a9c112e05991e;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$list$9e09da44f0278aa5;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$lookup$c76567b1fb804127;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$rebind$082655182723d0d0;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_rmi_registry_RegistryImpl$method_info$unbind$6f23bcd0c5499698;

// Static methods
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$help$ed44886e9089d90b(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_registry_RegistryImpl$method$version$248a7a0f0d347d2d(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_registry_RegistryImpl$vmethods {
	void	(*bind$251a9c112e05991e)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*list$9e09da44f0278aa5)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*lookup$c76567b1fb804127)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*rebind$082655182723d0d0)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *) _JC_JCNI_ATTR;
	void	(*unbind$6f23bcd0c5499698)(_jc_env *, struct _jc_gnu_java_rmi_registry_RegistryImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_registry_RegistryImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
	_jc_gnu_java_rmi_registry_RegistryImpl$vmethods	gnu_java_rmi_registry_RegistryImpl;
};

// Vtype
struct _jc_gnu_java_rmi_registry_RegistryImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_registry_RegistryImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs {
	struct _jc_java_util_Hashtable$object	*bindings;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl$refs {
    _jc_gnu_java_rmi_registry_RegistryImpl$sub_refs	gnu_java_rmi_registry_RegistryImpl;
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_registry_RegistryImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
    _jc_gnu_java_rmi_registry_RegistryImpl$sub_nonrefs	gnu_java_rmi_registry_RegistryImpl;
};

// Object instance structure
struct _jc_gnu_java_rmi_registry_RegistryImpl$object {
	_jc_gnu_java_rmi_registry_RegistryImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_registry_RegistryImpl$vtype	*vtype;
	_jc_gnu_java_rmi_registry_RegistryImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_registry_RegistryImpl$vtype _jc_gnu_java_rmi_registry_RegistryImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_registry_RegistryImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_registry_RegistryImpl$class_object;

#endif	/* _JC_gnu_java_rmi_registry_RegistryImpl_H_ */
